@@ -13,7 +13,7 @@ class Pyro4Migration(object):
 
     def migrate(self, agent):
         try:
-            if random.random() > 0.95:
+            if random.random() > 0.95 and len(agent.parent.get_agents()) > 1:
                 logger.debug("migrating!")
                 aggregate = self.__get_random_aggregate(agent)
                 logger.debug(aggregate.get_address())
